@@ -1,8 +1,9 @@
-from utils import get_user_name, welcome, load_game, number_to_game
-from Factory import Factory
+import utils
+from .utils import get_user_name, welcome, load_game, number_to_game
+from .Factory import Factory
 
 
-def mainGame():
+def main():
     user_name = get_user_name()
     welcome(user_name)
     game, level = load_game()
@@ -10,4 +11,6 @@ def mainGame():
     obj_game.print_data()
     obj_game.play
 
-#m = mainGame()
\ No newline at end of file
+
+if __name__ == '__main__':
+    main()
